function [net] = dlp(nin, nhidden, nout, fhidden, fout, bias)
%	
% net = dlp(nin, nhidden, nout, fhidden, fout, bias) 
%   Tworzy dwuwarstwowy perceptron o zadanej liczbie wejsc, wyjsc,
%   i okreslonej ilosci neuronow warstwy ukrytej,
%   neurony poszczegolnych warstw sieci przyjmuja okreslone funkcje aktywacji.
% 
% Argumenty wejsciowe:
%   nin  - ilosc wejsc sieci
%   nhidden - ilosc neuronow na warstwie ukrytej
%   nout - ilosc wyjsc sieci (rowna ilosci neuronow warstwy wyjsciowej)
%   fhidden, 
%   fout - nazwa funkcji aktywacji dla neuronow warstwy ukrytej oraz warstwy wyjsciowej
%     dozwolone sa nastepujace nazwy dla funkcji aktywacji:
%     'linear'  - funkcja liniowa
%     'hardlim' - unipolarna funkcja skoku
%     'hardlims'- bipolarna funkcja skoku
%     'logistic'- funkcja y = 1/(1+e^(-x))
%     'tanh'    - tangens hiperboliczny 
%   bias - dwuelementowy wektor zawierajacy flagi 0 i 1 dla kolejnych warstw sieci
%      1	neurony z biasem 
%      0	neurony bez biasu

%          
% Argumenty wyjsciowe:
%   net  - zmienna reprezentujaca utworzona siec
%     zmienna ta ma ustawione pola:
%       type = 'dlp' (typ sieci)  
%       nin          (ilosc wejsc sieci)
%       nhidden	(ilosc neuronow warstwy ukrytej sieci)
%       nout        (ilosc neuronow sieci)
%       hiddenfn   (funkcja aktywacji neuronow warstwy ukrytej sieci)
%       outfn       (funkcja aktywacji neuronow warstwy wyjsciowej sieci)
%       w1          (macierz wag neuronow warstwy ukrytej sieci - inicjowana zerami)
%       b1           (wektor biasow neuronow warstwy ukrytej sieci - inicjowany zerami)
%       wb1         (macierz zawierajaca wagi i biasy neuronow warstwy ukrytej sieci)
%       w2          (macierz wag neuronow warstwy wyjsciowej sieci - inicjowana zerami)
%       b2           (wektor biasow neuronow warstwy wyjsciowej sieci - inicjowany zerami)
%       wb2         (macierz zawierajaca wagi i biasy neuronow warstwy wyjsciowej sieci)
%
% Przyklad
%
%   n = dlp(2, 3, 1, ['hardlims', 'hardlims'])
%       tworzy siec dwuwarstwowa o dwoch wejsciach i jednym wyjsciu 
%       z trzema neuronami na warstwie ukrytej, wszystkie neurony sieci
%       maja bipolarna funkcje skoku jako funkcje aktywacji
%

net.type = 'dlp';
net.nin  = nin;
net.nout = nout;
net.nhidden = nhidden;

if sum(strcmp(fhidden, {'linear', 'hardlim', 'hardlims', 'logistic', 'tanh'})) == 0
  error('Niezdefiniowana funkcja aktywacji neuronow warstwy ukrytej\n');
end
  
if sum(strcmp(fout, {'linear', 'hardlim', 'hardlims', 'logistic', 'tanh'})) == 0
  error('Niezdefiniowana funkcja aktywacji neuronow warstwy wyjsciowej\n');
end

if length(bias) ~= 2
  error('Nieprawidlowy wymiar wektora zawierajacego informacje o biasach\n');
end  

net.hiddenfn = fhidden;
net.outfn = fout;

net.w1  = zeros(nhidden, nin);
if (bias(1))
  net.b1 = zeros(nhidden,1);
else
  net.b1 = [];
end
net.wb1 = [net.w1 net.b1];

net.w2  = zeros(nout, nhidden);
if (bias(2))
  net.b2  = zeros(nout,1);
else
  net.b2  = [];
end
net.wb2 = [net.w2 net.b2];