function [y] = dlpfwd(net, x)
%	
% y = dlpfwd(net, x) 
%   Oblicza wartosci sygnalow na wyjsciu perceptronu dwuwarstwowego dla 
%   podanego wektora sygnalow wejsciowych
% 
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron dwuwarstwowy
%   x    - kolumnowy wektor sygnalow wejsciowych lub 
%          macierz ktorej kolumny zawieraja kolejne wektory sygnalow wejsciowych
%          
% Argumenty wyjsciowe:
%   y    - kolumnowy wektor sygnalow wyjsciowych lub 
%          macierz ktorej kolumny zawieraja kolejne wektory sygnalow wyjsciowych
%
% Przyklad
%
%   n = dlp(2, 3, 1, ['hardlims', 'hardlims'])
%       tworzy siec dwuwarstwowa o dwoch wejsciach i jednym wyjsciu 
%       z trzema neuronami na warstwie ukrytej, wszystkie neurony sieci
%       maja bipolarna funkcje skoku jako funkcje aktywacji
%   n = dlpset(n, ones(3, 2), [1; -1; 0], [2 1 1], 2)
%       wagi neuronow pierwszej warstwy sieci sa ustawione na (1)
%       biasy neuronow pierwszej warstwy sieci sa ustawiane kolejno na (1), (-1) i (0)
%       wagi neuronu wyjsciowego sa ustawiane kolejno na (2), (1), (1)
%       bias neuron wyjsciowego jest ustawiany na (2)
%   y = dlpfwd(n, [1; 2])
%       zwraca wartosc na wyjsciu neuronu po podaniu na pierwsze wejcie sygnalu 1,
%       a na drugie sygnalu 2
%

if (strcmp(net.type, 'dlp') == 0) 
  error('Siec nie jest perceptronem dwuwarstwowym\n');
end

if (size(x,1) ~= net.nin)
  error('Nieprawidlowy rozmiar wektora sygnalow wejsciowych\n');
end

if (~isempty(net.b1))
  x = [x; ones(1, size(x,2))];
end
fi = net.wb1*x;

switch net.hiddenfn
  case 'linear'    
    y1 = fi;
  case 'hardlims'
    idx=find(fi==0); fi(idx)=-0.1; y1=sign(fi);
  case 'hardlim'
    idx=find(fi==0); fi(idx)=-0.1; y1=(sign(fi)+1)*0.5;
  case 'tanh'
    y1=tanh(fi);
  case 'logistic'
    y1=1./(1+exp(-fi));
end

if (~isempty(net.b2))
  y1 = [y1; ones(1, size(y1,2))];
end
fi = net.wb2*y1;

switch net.outfn
  case 'linear'    
    y = fi;
  case 'hardlims'
    idx=find(fi==0); fi(idx)=-0.1; y=sign(fi);
  case 'hardlim'
    idx=find(fi==0); fi(idx)=-0.1; y=(sign(fi)+1)*0.5;
  case 'tanh'
    y=tanh(fi);
  case 'logistic'
    y=1./(1+exp(-fi));
end

