function [] = dlpplt1(net, x, color)
%	
% dlpplt1(net, x, color) 
%   rysuje wykres przedstawiajacy wartosci sygnalow na wyjsciach neuronow sieci
%   w zaleznosci od wartosci sygnalu x podawanego na wejscie
%   siec musi miec dokladnie jedno wejscie 
% 
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron dwuwarstwowy
%   x    - wektor wierszowy zawierajacy wartosci sygnalow dla ktorych wyznaczana 
%          bedzie odpowiedz sieci dla potrzeb kreslonego wykresu
%   color - parametr opcjonalny, zawiera definicje kolorow jakimi
%          rysowane beda wykresy, domyslnie kolejnosc kolorow
%          odpowiada kolejnosci wybieranej przez funkcje plot,
%          jest to litera lub lancuch znakow (w zaleznosci od ilosci wyjsc sieci), 
%          kazdy ze znakow definiuje kolor, stosowane oznaczenia kolorow
%          odpowiadaja oznaczeniom stosowanym przez funkcje plot
%         
%
% Przyklad
%
%   n = dlp(1, 2, 1, 'hardlims', 'hardlims', [1, 1])
%       tworzy siec o jednym wejsciu, jednym wyjsciu i dwoch neuronach na warstwie ukrytej
%       neuron maja bias, funkcja aktywacji to bipolarna funkcja skoku
%   n = dlpset(n, [1; -1], [-2; 0], [1 2], 2)
%       waga i biasy neuronow sa rowne:
%   	  pierwszy neuron warstwy ukrytej: waga (1), bias (-2)
%	      drugi neuron warstwy ukrytej: waga (-1), bias (0)
%	      neuron warstwy wyjsciowej: 
%           waga zwiazana z pierwszym wejsciem (1), 
%           waga zwiazana z drugim wejsciem (2), bias (2)
%
%   dlpplt1(n, -5:0.5:5, 'r')
%       rysuje wykres w kolorze czerwonym
%       przedstawiajacy przetwarzanie sygnalow wejsciowych przez siec
%

if (strcmp(net.type, 'dlp') == 0) 
  error('Siec nie jest perceptronem dwuwarstwowym\n');
end

if (net.nin ~= 1)
  error('Nieprawidlowa ilosc wejsc sieci\n');
end

if (size(x,1) ~= 1)
  error('Nieprawidlowo przekazany wektor zawierajacy sygnaly wejsciowe\n');
end

if (nargin == 3) 
  if (length(color) < net.nout)
    error('Za malo znakow definiujacych kolory\n');
  end
end

y = dlpfwd(net, x);

if  (nargin < 3)
  plot(x, y);
else
  ih = ishold;
  if (~ih)
    if exist('OCTAVE_VERSION')
      clf; 
    else 
      cla;  
    end
    if (net.nout>1)
      hold on;
    end
  end
  for i=1: net.nout
     plot(x, y(i, :), [ '-' color(i)]);
  end
   if ((~ih) & (net.nout>1))
    hold off;
  end      
end

%xlabel('x');
%ylabel('y');
