function [net] = dlpset(net, w1, b1, w2, b2)
%	
% y = dlpset(net, w1, b1, w2, b2) 
%   Ustawia wagi i biasy sieci na podane przy wywolaniu funkcji
% 
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron dwuwarstwowy
%   w1    - macierz ktorej wiersze zawieraja wagi kolejnych neuronow warstwy ukrytej sieci
%   b1    - wektor kolumnowy ktorego elementy zawieraja biasy kolejnych 
%          neuronow warstwy ukrytej sieci
%   w2    - macierz ktorej wiersze zawieraja wagi kolejnych neuronow warstwy wyjsciowej sieci
%   b2    - wektor kolumnowy ktorego elementy zawieraja biasy kolejnych 
%          neuronow warstwy wyjsciowej sieci
%          
% Argumenty wyjsciowe:
%   net  - zmienna reprezentujaca siec zawierajaca nowe wartosci wag i biasow
%
% Przyklad
%
%   n = dlp(2, 3, 1, ['hardlims', 'hardlims'])
%       tworzy siec dwuwarstwowa o dwoch wejsciach i jednym wyjsciu 
%       z trzema neuronami na warstwie ukrytej, wszystkie neurony sieci
%       maja bipolarna funkcje skoku jako funkcje aktywacji
%   n = dlpset(n, ones(3, 2), [1; -1; 0], [2 1 1], 2)
%       wagi neuronow pierwszej warstwy sieci sa ustawione na (1)
%       biasy neuronow pierwszej warstwy sieci sa ustawiane kolejno na (1), (-1) i (0)
%       wagi neuronu wyjsciowego sa ustawiane kolejno na (2), (1), (1)
%       bias neuron wyjsciowego jest ustawiany na (2)
%

if (strcmp(net.type, 'dlp') == 0) 
  error('Siec nie jest perceptronem dwuwarstwowym\n');
end

if ((size(w1,1) ~= net.nhidden) | (size(w1,2) ~= net.nin))
  error('Nieprawidlowy rozmiar macierzy wag neuronow warstwy ukrytej\n');
end

if ((size(w2,1) ~= net.nout) | (size(w2,2) ~= net.nhidden))
  error('Nieprawidlowy rozmiar macierzy wag neuronow warstwy wyjsciowej\n');
end

if (~isempty(net.b1) & ((size(b1,1) ~= net.nhidden) | (size(b1,2) ~= 1)))
  error('Nieprawidlowy rozmiar wektora biasow neuronow warstwy ukrytej\n');
end

if (isempty(net.b1) & ~isempty(b1))
  error('Neurony warstwy ukrytej sieci nie maja biasow\n');
end

if (~isempty(net.b2) & ((size(b2,1) ~= net.nout) | (size(b1,2) ~= 1)))
  error('Nieprawidlowy rozmiar wektora biasow neuronow warstwy ukrytej\n');
end

if (isempty(net.b1) & ~isempty(b1))
  error('Neurony warstwy ukrytej sieci nie maja biasow\n');
end

if ((size(b1,1) ~= net.nhidden) | (size(b1,2) ~= 1))
  error('Nieprawidlowy rozmiar wektora biasow warstwy ukrytej sieci\n');
end

if ((size(b2,1) ~= net.nout) | (size(b2,2) ~= 1))
  error('Nieprawidlowy rozmiar wektora biasow warstwy wyjsciowej sieci\n');
end

net.w1  = w1;
net.b1  = b1;
net.wb1 = [w1 b1];

net.w2  = w2;
net.b2  = b2;
net.wb2 = [w2 b2];