function [net] = slp(nin, nout, func, bias)
%	
% net = slp(nin, nout, func, bias) 
%   Tworzy jednowarstwowy perceptron o zadanej liczbie wejsc, wyjsc,
%   neurony sieci przyjmuja okreslona funkcje aktywacji.
% 
% Argumenty wejsciowe:
%   nin  - ilosc wejsc sieci
%   nout - ilosc wyjsc sieci (rowna ilosci neuronow)
%   func - funkcja aktywacji, moze ona przyjmowac wartosci
%     'linear'  - funkcja liniowa
%     'hardlim' - unipolarna funkcja skoku
%     'hardlims'- bipolarna funkcja skoku
%     'logistic'- funkcja y = 1/(1+e^(-x))
%     'tanh'    - tangens hiperboliczny 
%   bias - okresla czy neurony sieci posiadaja bias
%     1 - neurony z biasem
%     0 - neurony bez biasu
%     domyslnie bias=1
%          
% Argumenty wyjsciowe:
%   net  - zmienna reprezentujaca utworzona siec
%     zmienna ta ma ustawione pola:
%       type = 'slp' (typ sieci)  
%       nin          (ilosc wejsc sieci)
%       nout         (ilosc neuronow sieci)
%       actfn        (funkcja aktywacji neuronow sieci)function:
%       w            (macierz wag neuronow sieci - inicjowana zerami)
%       b            (wektor biasow - inicjowany zerami)
%       wb           (macierz zawierajaca wagi i biasy sieci)
%
% Przyklad
%
%   n = slp(2, 1, 'hardlims')
%       tworzy neuron z biasem o dwoch wejsciach z bipolarna funkcja skoku
%

if (nargin < 4)
  bias =1;
end;

net.type = 'slp';
net.nin  = nin;
net.nout = nout;

if sum(strcmp(func, {'linear', 'hardlim', 'hardlims', 'logistic', 'tanh'})) == 0
  error('Niezdefiniowana funkcja aktywacji\n');
else
  net.actfn = func;
end

net.w  = zeros(nout, nin);
if (bias)
  net.b  = zeros(nout,1);
else 
  net.b = [];
end

net.wb = [net.w net.b];