function [y] = slpfwd(net, x)
%	
% y = slpfwd(net, x) 
%   Oblicza wartosci sygnalow na wyjsciu perceptronu jednowarstwowego dla 
%   podanego wektora sygnalow wejsciowych
% 
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron jednowarstwowy
%   x    - kolumnowy wektor sygnalow wejsciowych lub 
%          macierz ktorej kolumny zawieraja kolejne wektory sygnalow wejsciowych
%          
% Argumenty wyjsciowe:
%   y    - kolumnowy wektor sygnalow wyjsciowych lub 
%          macierz ktorej kolumny zawieraja kolejne wektory sygnalow wyjsciowych
%
% Przyklad
%
%   n = slp(2, 1, 'hardlims')
%       tworzy neuron z biasem o dwoch wejsciach z bipolarna funkcja skoku
%   n = slpset(n, [-1 1], 3)
%       waga zwiazana z pierwszym wejsciem jest ustawiana na (-1)
%       waga zwiazana z drugim wejsciem jest ustawiana na (1)
%       bias jest ustawiany na (3)
%
%   y = slpfwd(n, [1; 2])
%       zwraca wartosc na wyjsciu neuronu po podaniu na pierwsze wejcie sygnalu 1,
%       a na drugie sygnalu 2
%

if (strcmp(net.type, 'slp') == 0) 
  error('Siec nie jest perceptronem jednowarstwowym\n');
end

if (size(x,1) ~= net.nin)
  error('Nieprawidlowy rozmiar wektora sygnalow wejsciowych\n');
end

if (~isempty(net.b))
  x = [x; ones(1, size(x,2))];
end
fi = net.wb*x;

switch net.actfn
  case 'linear'    
    y = fi;
  case 'hardlims'
    idx=find(fi==0); fi(idx)=-0.1; y=sign(fi);
  case 'hardlim'
    idx=find(fi==0); fi(idx)=-0.1; y=(sign(fi)+1)*0.5;
  case 'tanh'
    y=tanh(fi);
  case 'logistic'
    y=1./(1+exp(-fi));
end