function [] = slpplt1(net, x, color)
%	
% slpplt1(net, x) 
%   rysuje wykres przedstwiajacy wartosci sygnalow na wyjsciach neuronow sieci
%   w zaleznosci od wartosci sygnalu x podawanego na wejscie
%   siec musi miec dokladnie jedno wejscie 
% 
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron jednowarstwowy
%   x    - wektor wierszowy zawierajacy wartosci sygnalow dla ktorych wyznaczana 
%          bedzie odpowiedz sieci dla potrzeb kreslonego wykresu
%   color - parametr opcjonalny, zawiera definicje kolorow jakimi
%          rysowane beda wykresy, domyslnie kolejnosc kolorow
%          odpowiada kolejnosci wybieranej przez funkcje plot,
%          jest to litera lub lancuch znakow (w zaleznosci od ilosci wyjsc sieci), 
%          kazdy ze znakow definiuje kolor, stosowane oznaczenia kolorow
%          odpowiadaja oznaczeniom stosowanym przez funkcje plot
%         
%
% Przyklad
%
%   n = slp(1, 2, 'hardlims')
%       tworzy perceptron jednowarstwowy, funkcja aktywacji to bipolarna funkcja skoku
%   n = slpset(n, [2; -1], [3; 1])
%       waga pierwszego neuronu jest ustawiana na (2) a bias na (3)
%       waga drugiego neuronu jest ustawiana na (-1) a bias na (1)
%
%   slpplt1(n, -5:0.5:5, 'rg')
%       wykres w kolorze czerwonym przedstawia przetwarzanie 
%       sygnalow wejsciowych przez pierwszy neuron
%       wykres w kolorze zielonym przedstawiaja przetwarzanie 
%       sygnalow wejsciowych przez drugi neuron
%

if (strcmp(net.type, 'slp') == 0) 
  error('Siec nie jest perceptronem jednowarstwowym\n');
end

if (net.nin ~= 1)
  error('Nieprawidlowa ilosc wejsc sieci\n');
end

if (size(x,1) ~= 1)
  error('Nieprawidlowo przekazany wektor zawierajacy sygnaly wejsciowe\n');
end

if (nargin == 3) 
  if  (length(color) < net.nout)
    error('Za malo znakow definiujacych kolory\n');
  end  
end

y = slpfwd(net, x);

if  (nargin < 3)
  plot(x, y);
else
  ih = ishold;
  if (~ih)
    if exist('OCTAVE_VERSION')
      clf; 
    else 
      cla;  
    end 
    if (net.nout>1)
      hold on;
    end
  end 
  for i=1: net.nout
     plot(x, y(i, :), ['-' color(i)]);
  end
   if ((~ih) & (net.nout>1))
    hold off;
  end      
end

%xlabel('x');
%ylabel('y');
