function [] = slpplt2(net, x1, x2, fig)
%	
% slpplt2(net, x1, x2, fig) 
%   rysuje wykres przedstwiajacy wartosci sygnalu na wyjsciu neuronu o dwoch 
%   wejsciach w zaleznosci od wartosci sygnalow podawanych na wejscie
%   neuron musi miec dokladnie dwa wejscia
%
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron jednowarstwowy
%   x1   - wektor wierszowy zawierajacy wartosci sygnalow podawnych na 
%          pierwsze wejscie neuronu
%   x2   - wektor wierszowy zawierajacy wartosci sygnalow podawnych na drugie 
%          wejscie neuronu
%          domyslnie x2 = x1
%   fig  - wartosc liczbowa okreslajaca rodzaj wykresu
%          1 - wykres powierzchniowy 
%          2 - wykres poziomicowy 
%          domyslnie wybierany jest wykres 1
%
% Przyklad
%
%   n = slp(2, 1, 'hardlims')
%       tworzy neuron z biasem o dwoch wejsciach z bipolarna funkcja skoku
%   n = slpset(n, [-1 2], 3)
%       waga zwiazana z pierwszym wejsciem neuronu jest ustawiana na (-1)
%       waga zwiazana z drugim wejsciem neuronu jest ustawiana na (2)
%       bias jest ustawiany na (3)
%
%   slpplt2(n, -5:0.5:5)
%       rysuje wykres powierzchniowy przedstawiajacy przetwarzanie sygnalow 
%       wejsciowych przez neuron, na pierwsze i drugie wejscie neuronu podawane 
%       sa sygnaly z przedzialu [-5, 5]
%

n = nargin;

if (n < 3) 
  x2 = x1;
end

if (n < 4)
  fig = 1;
end

if ((n == 3) & (length(x2)==1))
  fig = x2; x2 = x1;
end

if (strcmp(net.type, 'slp') == 0) 
  error('Siec nie jest perceptronem jednowarstwowym\n');
end

if (net.nin ~= 2)
  error('Nieprawidlowa ilosc wejsc sieci\n');
end

if (net.nout ~= 1)
  error('Funkcja rysuje wykresy wylacznie dla pojedynczych neuronow\n');
end

if ((size(x1,1) ~= 1) | (size(x2,1) ~= 1))
  error('Nieprawidlowo przekazany wektor zawierajacy sygnaly wejsciowe\n');
end

[x_1, x_2] = meshgrid(x1, x2); 
nx = [reshape(x_1, 1, size(x_1,1)*size(x_1,2)); reshape(x_2, 1, size(x_1,1)*size(x_1,2))];

ny = slpfwd(net, nx);
y = reshape(ny, size(x_1,1), size(x_1,2));

switch fig
  case 1
    surf(x_1, x_2, y);
  case 2
    cfun = 'contourf';
    if exist('OCTAVE_VERSION')
      cfun = 'contour';
    end
    switch net.actfn
      case 'hardlims' 
        feval(cfun, x_1, x_2, y, [0 0]);
      case 'hardlim'
        feval(cfun, x_1, x_2, y, [0.5 0.5]);
      otherwise
        feval(cfun, x_1, x_2, y);
     end 
end

xlabel('x1');
ylabel('x2');
zlabel('y');
