function [] = slppltdb(net, x1, x2, color)
%	
% slppltdb(net, x1, x2) 
%   rysuje podzial przestrzeni wejsciowej generowany przez siec o dwoch wejsciach
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron jednowarstwowy
%   x1   - dwuelementowy wektory wierszowy zawierajacy dolna i gorna wartosc 
%          sygnalu podawnego na pierwsze wejscie sieci
%   x2   - dwuelementowy wektory wierszowy zawierajacy dolna i gorna wartosc 
%          sygnalu podawnego na drugie wejscie sieci
%          domyslnie x2 = x1
%   color - parametr opcjonalny, zawiera definicje kolorow jakimi
%          rysowane beda wykresy, domyslnie kolejnosc kolorow
%          odpowiada kolejnosci wybieranej przez funkcje plot,
%          jest to litera lub lancuch znakow (w zaleznosci od ilosci wyjsc sieci), 
%          kazdy ze znakow definiuje kolor, stosowane oznaczenia kolorow
%          odpowiadaja oznaczeniom stosowanym przez funkcje plot
%
% Przyklad
%
%   n = slp(2, 2, 'hardlims')
%       tworzy siec jednowarstwowa zbudowana z dwoch neuronow o dwoch wejsciach
%       z bipolarna funkcja skoku
%   n = slpset(n, [1 2; 2 0], [3; 0])
%       waga zwiazana z pierwszym wejsciem pierwszego neuronu ustawiana na (1)
%       waga zwiazana z drugim wejsciem pierwszego neuronu jest ustawiana na (2)
%       bias pierwszego neuronu jest ustawiany na (3)
%       waga zwiazana z pierwszym wejsciem drugiego neuronu jest ustawiana na (2)
%       waga zwiazana z drugim wejsciem drugiego neuronu jest ustawiana na (0)
%       bias drugiego neuronu jest ustawiany na (0)
%
%   slppltdb(n, [-5 5])
%       rysuje podzial przestrzeni wejsciowej

n = nargin;

c='rgbmc';  

if (n < 3) 
  x2 = x1;
elseif (n<4)
  if (isstr(x2))
    c = x2; x2 = x1;
  end
else
  c = color;
end

nc = length(c);

if (strcmp(net.type, 'slp') == 0) 
  error('Siec nie jest perceptronem jednowarstwowym');
end

if (net.nin ~= 2)
  error('Nieprawidlowa ilosc wejsc sieci');
end

if ((size(x1,1) ~= 1) | (size(x1,2) ~= 2) | (size(x2,1) ~= 1) | (size(x2,2) ~= 2))
  error('Nieprawidlowo przekazany wektor zawierajacy zakres sygnalow wejsciowych');
end

axis([x1 x2]); %axis('equal');
ih = ishold;
if (~ih)
  if exist('OCTAVE_VERSION')
     clf; 
  else 
     cla;  
  end
  if (net.nout>1)
    hold on;
  end
end
grid on;

for i=1:net.nout
  p = [];
  if (net.w(i,2)~=0)
    for j=1:2
      pp=[x1(j); -net.w(i,1)/net.w(i,2)*x1(j)-net.b(i)/net.w(i,2)];
      if ( (pp(1) >= x1(1)) & (pp(1) <= x1(2)) & (pp(2) >= x2(1)) & (pp(2) <= x2(2)) ) p=[p pp]; end
    end
  end 
  if (net.w(i,1)~=0)
    for j=1:2  
      pp=[-net.w(i,2)/net.w(i,1)*x2(j)-net.b(i)/net.w(i,1); x2(j)];
      if ( (pp(1) >= x1(1)) & (pp(1) <= x1(2)) & (pp(2) >= x2(1)) & (pp(2) <= x2(2)) ) p=[p pp]; end
    end
  end

  up = [];
  for j=1 : size(p,2)
    ex = 0;
    for k=1 : size(up,2)
      if (all(abs(up(:,k)-p(:,j))<0.01)); ex = 1; end;
    end
    if (~ex); up = [up p(:,j)]; end
  end

  if (size(up,2)>=2)
    up = up(:,1:2);  
    if (net.w(i,2)~=0)
      x = linspace(up(1,1), up(1,2));  y = -net.w(i,1)/net.w(i,2)*x-net.b(i)/net.w(i,2);
    elseif (net.w(i,1)~=0)
      y = linspace(up(2,1), up(2,2));  x = -net.w(i,2)/net.w(i,1)*y-net.b(i)/net.w(i,1);
    end
    l = norm(up(:,1)-up(:,2),2)/10;
    isp = round(rand(1)*(length(x)/2-1))+length(x)/4;
    nw = net.w(i,:)/norm(net.w(i,:))*l;
    sp = [x(isp); y(isp)]; ep = sp + nw' ;
    cc = sprintf('%s',c(rem(i-1,nc)+1));
    plot(x, y, ['-',cc],   [sp(1) ep(1)], [sp(2) ep(2)], ['-',cc],  ep(1), ep(2), ['+',cc]);    
  end
end

if ((~ih) & (net.nout>1))
  hold off;
end      
axis('equal');
  
%xlabel('x1');
%ylabel('x2');

