function [net] = slpset(net, w, b)
%	
% y = slpset(net, w, b) 
%   Ustawia wagi i biasy sieci na podane przy wywolaniu funkcji
% 
% Argumenty wejsciowe:
%   net  - zmienna reprezentujaca perceptron jednowarstwowy
%   w    - macierz ktorej wiersze zawieraja wagi kolejnych neuronow sieci
%   b    - wektor kolumnowy ktorego elementy zawieraja biasy kolejnych 
%          neuronow sieci
%          domyslnie wektor o elementach rownych zero
%          
% Argumenty wyjsciowe:
%   net  - zmienna reprezentujaca siec zawierajaca nowe wartosci wag i biasow
%
% Przyklad
%
%   n = slp(2, 1, 'hardlims')
%       tworzy neuron z biasem o dwoch wejsciach z bipolarna funkcja skoku
%   n = slpset(n, [-1 1], 3)
%       waga zwiazana z pierwszym wejsciem jest ustawiana na (-1)
%       waga zwiazana z drugim wejsciem jest ustawiana na (1)
%       bias jest ustawiany na (3)
%

if (strcmp(net.type, 'slp') == 0) 
  error('Siec nie jest perceptronem jednowarstwowym\n');
end

if ((size(w,1) ~= net.nout) | (size(w,2) ~= net.nin))
  error('Nieprawidlowy rozmiar macierzy wag\n');
end

if (nargin < 3)
  if (isempty(net.b))
    b = [];
  else
    b = zeros(net.nout, 1);
  end
end

if (~isempty(net.b) & ((size(b,1) ~= net.nout) | (size(b,2) ~= 1)))
  error('Nieprawidlowy rozmiar wektora biasow\n');
end


if (isempty(net.b) & ~isempty(b))
  error('Neurony sieci nie maja biasow\n');
end


net.w  = w;
net.b  = b;
net.wb = [w b];